import React, { useEffect, isValidElement, Children, cloneElement, createElement } from 'react';
import Highlighter from 'react-highlight-words';

var shouldPierce = function shouldPierce(child) {
  return isValidElement(child) && typeof child.type === 'function' && child.type.name === 'Pierce';
};

var Search = function Search(_ref) {
  var children = _ref.children,
      onDone = _ref.onDone,
      test = _ref.test,
      value = _ref.value,
      highlighterProps = _ref.highlighterProps,
      _ref$highlightTag = _ref.highlightTag,
      highlightTag = _ref$highlightTag === void 0 ? 'mark' : _ref$highlightTag;
  var count = 0;

  var counterTag = function counterTag(_ref2) {
    var children = _ref2.children;
    count++;
    return createElement(highlightTag, null, children);
  };

  var Highlight = function Highlight(_ref3) {
    var child = _ref3.child;
    return React.createElement(Highlighter, Object.assign({}, highlighterProps, {
      searchWords: [value],
      textToHighlight: child,
      highlightTag: counterTag
    }));
  };

  var deepHighlight = function deepHighlight(child) {
    if (test && typeof child === 'string') {
      return React.createElement("mark", {
        key: child
      }, child);
    }

    if (typeof child === 'string') {
      return React.createElement(Highlight, {
        child: child
      });
    }

    if (shouldPierce(child)) {
      var piercedChildren = child.props.children;

      var pierceChildren = function pierceChildren(innerChild) {
        var prototype = innerChild.type.prototype;

        if (prototype && prototype.isReactComponent) {
          return new innerChild.type(innerChild.props).render();
        } else {
          return innerChild.type(innerChild.props);
        }
      };

      return deepHighlight(Children.map(piercedChildren, pierceChildren));
    }

    if (isValidElement(child)) {
      var props = child.props;

      var _children = deepHighlight(props.children);

      return cloneElement(child, props, _children);
    }

    if (Array.isArray(child)) {
      return Children.map(child, deepHighlight);
    }
  };

  useEffect(function () {
    onDone && onDone({
      count: count
    });
  });
  return deepHighlight(children) || null;
};

var Pierce = function Pierce(_ref4) {
  var children = _ref4.children;
  return children;
};

export default Search;
export { Pierce };
//# sourceMappingURL=index.modern.js.map
